@@ -68,12 +68,20 @@ def review(openai_key, assistant_id, token, repo, branch, message, gh_before, sh
           'message': response['message'].get('provided', ''),
           'suggested': response['message'].get('generated', ''),
           'adherence': int(response['message']['adherence'].get('score', 0)),
+          'adherence_comment': response['message']['adherence'].get('comment', ''),  # New field
+          'complexity_comment': response['codeComplexity'].get('comment', ''),       # New field
           'vulnerability': int(response['codeVulnerability'].get('score', 0)),
+          'vulnerability_comment': response['codeVulnerability'].get('comment', ''), # New field
           'singleResponsibility': int(response['codeSOLID']['singleResponsibility'].get('score', 0)),
+          'singleResponsibility_comment': response['codeSOLID']['singleResponsibility'].get('comment', ''),  # New field
           'openClosed': int(response['codeSOLID']['openClosed'].get('score', 0)),
+          'openClosed_comment': response['codeSOLID']['openClosed'].get('comment', ''),  # New field
           'liskovSubstitution': int(response['codeSOLID']['liskovSubstitution'].get('score', 0)),
+          'liskovSubstitution_comment': response['codeSOLID']['liskovSubstitution'].get('comment', ''),  # New field
           'interfaceSegregation': int(response['codeSOLID']['interfaceSegregation'].get('score', 0)),
+          'interfaceSegregation_comment': response['codeSOLID']['interfaceSegregation'].get('comment', ''),  # New field
           'dependencyInversion': int(response['codeSOLID']['dependencyInversion'].get('score', 0)),
+          'dependencyInversion_comment': response['codeSOLID']['dependencyInversion'].get('comment', ''),  # New field
       }, {"user": author, "sha": sha, "repo": repo, "branch": branch, "issue": str(issue_number), "comment": str(comment_id)}))
     except Exception as e:
         print(f"Unexpected error: {e}")
